Crate aranya_policy_compiler

Crate aranya_policy_compiler 

The Aranya policy compiler.

See the policy book for more information on the policy language.

Re-exports

pub use compile::*;

Modules

compile
validate

Structs

ActionAnalyzer
Ensures that all branches publish a command.
FinishAnalyzer
Ensures that all branches enter a finish block before exiting.
FunctionAnalyzer
Ensures that all function branches return a value.
TraceAnalyzer
Traces compiled code paths to prove properties with Analyzers. See TraceAnalyzerBuilder to construct a TraceAnalyzer.
TraceAnalyzerBuilder
Builds a TraceAnalyzer by adding a series of Analyzer implementations with add_analyzer and calling build.
TraceError
TraceFailure
Failed results from one analyzer on one code path
ValueAnalyzer
Ensures that all values that are read have first been defined.

Enums

AnalyzerStatus
Status returned from analyzers

Traits

Analyzer
AnalyzerClone